Large-scale genome sampling reveals unique immunity and metabolic adaptations in bats

Contact Yocelyn Gutierrez Yoce_pf@hotmail.com

##1.Data format
#Rename sequences headers for shorter IDs
#Assuming all cds and proteins sequences are in the same directory


for f in *.faa; do SUBNAME=$(basename $f | awk -F'[_]' '{print $1}'); PX=${SUBNAME:0:4} && PX=${PX^^}; ./seqkit replace -p '.+' -r $PX'_{nr}' $f > $SUBNAME'_proteins.faa'; done

for f in *.fasta; do SUBNAME=$(basename $f | awk -F'[_]' '{print $1}'); PX=${SUBNAME:0:4} && PX=${PX^^}; ./seqkit replace -p '.+' -r $PX'_{nr}' $f > $SUBNAME'_cds.fasta'; done

#Concatenate cds sequences for downstream analysis
cat *_cds.fasta > all_species_cds.fasta


##2.Run Orthofinder for homology inference

#2.1 Create a directory to store proteins files
WORKDIR="1.renamed_proteins"
mkdir $WORKDIR

for f in *faa; do mv $f $WORKDIR/; done

#2.2 Run Orthofinder

ORTHO="/home/dmorenos/software/OrthoFinder"
ORTHOUT="2.orthofinder_results"
$ORTHO/orthofinder -f $WORKDIR -t 36 -o $ORTHOUT

 
##3.Ultrametric tree using single copy genes

#3.1 Concatenate single copy genes
TREEDIR="3.ultrameric_tree"
cd $TREEDIR

#Copy fasta files for single copy orthogroups
for f in ../$ORTHOUT/Results/Single_Copy_Orthologue_Sequence/*fa; do cp $f .; done

#Create a symbolic link for the fasta file containing all cds sequences.
ln -s ../all_species_cds.fasta

#Obtain headers for each sequences contained in its respective orthogroups

for f in OG*; do PX=$(basename $f | awk -F '.' '{print $1}'); grep ">" $f | sed 's/>//g' > $PX'_headers.tmp'; done 

#Extract cds sequences for each single copy orthogroup

for f in *_headers.tmp; do PX=$(basename $f | awk -F '_' '{print $1}'); python extract_cds_seq.py all_species_cds.fasta $f $PX; done

rm *_headers.tmp

#Remove numbers from headers to only keep the species prefix
for f in *fa; do sed -i 's/_.*$//g' $f; done #aminoacids sequences
for f in *single_cds.fasta; do sed -i 's/_.*$//g' $f; done #cds sequences

#Concatenate single copy genes in a single sequence
seqkit concat *.fa > single_copy.faa
seqkit concat *single_cds.fasta > single_copy_cds.fasta

#Ultrametric tree
#Alignment sequences
mafft --anysymbol --parttree --retree 1 --thread 12 single_copy.faa > align_single_copy.faa
mafft --anysymbol --parttree --retree 1 --thread 12 single_copy_cds.fasta >  align_single_copy_cds.fasta

#Evolutionary model
prottest3 -i align_single_copy.faa -o single_copy.prottest -t1 -t2 -tc 0.8 -AIC -BIC -S 2 
java -jar jModelTest.jar -d align_single_copy_cds.fasta -i -f -g 4 -BIC -AIC -AICc -DT -v -a -w -tr 10 -o single_copy_cds.modelTest

#Phylogenetic Tree
raxmlHPC-PTHREADS -f a -p 12345 -m PROTCATJTT -s align_single_copy.faa -n single_copy.tree -# 10000 -T 20 -x 100

#Estimation of species divergence
# The tree (single_copy.tree) was rooted using FigTree

#Estimation of substitution rate using the files: align_single_copy_cds.fasta, single_copy.tree and single_copy_cds.modelTest (GTR+C = substitution model 7; Strick clock model = 1)

baseml baseml.ctl

#Estimation of Gradient and Hessian (using a tree with constraints and GTR+C = substitution model 7)

mcmctree mcmctree.ctl

#Estimation of time and rate [calculating manually the gamma prior for rate for genes (rgene_gamma) using the baseml output and 60,000 iterations of MCMC]

mcmctree mcmctree2.ctl







